==> qmmp-0.12.4.tar.bz2: qmmp-0.12.4/src/plugins/Input/opus/translations/opus_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>DecoderOpusFactory</name>
    <message>
        <location filename="../decoderopusfactory.cpp" line="43"/>
        <source>Opus Plugin</source>
        <translation>Plugin Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="46"/>
        <source>Ogg Opus Files</source>
        <translation>File Opus Ogg</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="122"/>
        <source>About Opus Audio Plugin</source>
        <translation>Tentang Plugin Audio Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="123"/>
        <source>Qmmp Opus Audio Plugin</source>
        <translation>Plugin Audio Opus Qmmp </translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="124"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="125"/>
        <source>This plugin includes code from TagLib library</source>
        <translation>Plugin ini mencakup kode dari pustaka TagLib</translation>
    </message>
</context>
<context>
    <name>OpusMetaDataModel</name>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="50"/>
        <source>Version</source>
        <translation>Versi</translation>
    </message>
</context>
</TS>

==> qmmp-0.12.14.tar.bz2: qmmp-0.12.14/src/plugins/Input/opus/translations/opus_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>DecoderOpusFactory</name>
    <message>
        <location filename="../decoderopusfactory.cpp" line="43"/>
        <source>Opus Plugin</source>
        <translation>Plugin Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="46"/>
        <source>Ogg Opus Files</source>
        <translation>File Opus Ogg</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="129"/>
        <source>About Opus Audio Plugin</source>
        <translation>Tentang Plugin Audio Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="130"/>
        <source>Qmmp Opus Audio Plugin</source>
        <translation>Plugin Audio Opus Qmmp </translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="131"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="132"/>
        <source>This plugin includes code from TagLib library</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpusMetaDataModel</name>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="49"/>
        <source>Version</source>
        <translation>Versi</translation>
    </message>
</context>
</TS>
